@@ -86,10 +86,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if HAVE_MALLOC_H
-#    include <malloc.h>
-#endif
-
 /* Programming interface to dynamic linking loader */
 #if HAVE_DLFCN_H
 #    include <dlfcn.h>
@@ -114,9 +110,6 @@
                              Define constants
 ******************************************************************************/
 
-#define LCMAPS_MOD_HOME LCMAPS_LIB_HOME"/modules" /* default directory for the
-						     LCMAPS plugins/modules */
-
 #ifndef NUL
 #define NUL '\0' /*!< NUL character \internal */
 #endif
@@ -165,13 +158,6 @@ enum lcas_proctype_e
     ENDOFPROCS /*< this is the last enumeration value */
 };
 
-/*!
-    \typedef lcas_proc_t
-    \brief this type corresponds to the types of the plugin interface functions
-    \internal
-*/
-typedef int (*lcas_proc_t)();
-
 /*!
     \typedef lcas_plugindl_t
     \brief the type definition of the plugin authorization module structure
@@ -562,7 +548,7 @@ static lcas_plugindl_t * PluginInit(
     char *                 pdb=NULL;
 #endif
     void *                 plugin_handle;
-    lcas_proc_t            plugin_procs[MAXPROCS];
+    lcas_proc_t            plugin_procs[MAXPROCS] = {NULL};
     lcas_plugindl_t *      pplugin=NULL;
     int                    i;
     int                    retval;
@@ -741,7 +727,7 @@ static lcas_plugindl_t * PluginInit(
 #if 0
     retval=(*(pplugin->procs[INITPROC]))(pplugin->pluginargs);
 #endif
-    retval=(*(pplugin->procs[INITPROC]))(pplugin->argc,pplugin->argv);
+    retval=((lcas_init_proc_t)pplugin->procs[INITPROC])(pplugin->argc,pplugin->argv);
     if (retval != LCAS_MOD_SUCCESS )
     {
         lcas_log(0,"lcas.mod-PluginInit(): \"plugin_initialize()\" failed\n");
@@ -923,7 +909,7 @@ static int clean_plugin_list(
         lcas_plugindl_t * plugin_next;
         int               i;
 
-        rc = plugin_entry->procs[TERMPROC]();
+        rc = ((lcas_term_proc_t)plugin_entry->procs[TERMPROC])();
         if (rc != LCAS_MOD_SUCCESS)
         {
             lcas_log(0,"lcas.mod-clean_plugin_list(): failed to terminate plugin module %s\n",
@@ -1236,7 +1222,7 @@ int lcas_run_va(
     authmod_entry=authmod_list;
     while (authmod_entry)
     {
-        rc = authmod_entry->procs[AUTHPROC](request, lcas_cred);
+        rc = ((lcas_auth_proc_t)authmod_entry->procs[AUTHPROC])(request, lcas_cred);
         if (rc != LCAS_MOD_SUCCESS)
         {
             lcas_log_debug(0,"%s: authorization failed for standard module %s\n",
@@ -1260,9 +1246,9 @@ int lcas_run_va(
 
         /* Try AUTHPROCX509 if available, otherwise fall back to AUTHPROC */
         if (plugin_entry->procs[AUTHPROCX509])
-            rc = plugin_entry->procs[AUTHPROCX509](request, lcas_cred, px509, px509_chain);
+            rc = ((lcas_authx509_proc_t)plugin_entry->procs[AUTHPROCX509])(request, lcas_cred, px509, px509_chain);
         else
-            rc = plugin_entry->procs[AUTHPROC](request, lcas_cred);
+            rc = ((lcas_auth_proc_t)plugin_entry->procs[AUTHPROC])(request, lcas_cred);
         if (rc != LCAS_MOD_SUCCESS)
         {
             lcas_log_debug(0,"%s: authorization failed for plugin %s\n",
